from setuptools import setup

setup(name='Distribution_Gauss_Bin',
      version='0.2',
      description='Gaussian and Binomial distributions',
      packages=['Distribution_Gauss_Bin'],
      author='Nimish Soni',
      author_email ='nimish.soni@gmail.com',
      zip_safe=False)
